# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Browser(Model):
    """Browser.

    All required parameters must be populated in order to send to Azure.

    :param product: Required. Product of the browser. Possible values are
     'chrome', 'firefox', 'edge', 'safari'.
    :type product: str
    :param major: Required. Major version of the browser.
    :type major: int
    :param version: Required. Exact version of the browser.
    :type version: str
    """

    _validation = {
        'product': {'required': True},
        'major': {'required': True},
        'version': {'required': True},
    }

    _attribute_map = {
        'product': {'key': 'product', 'type': 'str'},
        'major': {'key': 'major', 'type': 'int'},
        'version': {'key': 'version', 'type': 'str'},
    }

    def __init__(self, *, product: str, major: int, version: str, **kwargs) -> None:
        super(Browser, self).__init__(**kwargs)
        self.product = product
        self.major = major
        self.version = version
