# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

try:
    from .device_py3 import Device
    from .os_py3 import Os
    from .browser_py3 import Browser
    from .base_profile_py3 import BaseProfile
    from .base_profile_preview_py3 import BaseProfilePreview
    from .base_profile_search_parameters_py3 import BaseProfileSearchParameters
    from .browser_cookie_py3 import BrowserCookie
    from .cookie_request_py3 import CookieRequest
    from .webgl_spoofing_options_py3 import WebglSpoofingOptions
    from .webgl_spoofing_type_webgl_spoofing_options_multi_level_choice_py3 import WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice
    from .timezone_spoofing_type_timezone_multi_level_choice_py3 import TimezoneSpoofingTypeTimezoneMultiLevelChoice
    from .geolocation_spoofing_options_py3 import GeolocationSpoofingOptions
    from .geolocation_spoofing_type_geolocation_spoofing_options_multi_level_choice_py3 import GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice
    from .server_py3 import Server
    from .proxy_connection_type_server_multi_level_choice_py3 import ProxyConnectionTypeServerMultiLevelChoice
    from .web_rtc_spoofing_options_py3 import WebRtcSpoofingOptions
    from .web_rtc_spoofing_type_web_rtc_spoofing_options_multi_level_choice_py3 import WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice
    from .font_spoofing_type_font_ilist_multi_level_choice_py3 import FontSpoofingTypeFontIListMultiLevelChoice
    from .plugin_spoofing_type_plugin_ilist_multi_level_choice_py3 import PluginSpoofingTypePluginIListMultiLevelChoice
    from .screen_spoofing_type_screen_size_multi_level_choice_py3 import ScreenSpoofingTypeScreenSizeMultiLevelChoice
    from .create_profile_request_py3 import CreateProfileRequest
    from .load_profile_request_py3 import LoadProfileRequest
    from .preference_py3 import Preference
    from .problem_response_py3 import ProblemResponse, ProblemResponseException
    from .status_response_py3 import StatusResponse
    from .profile_preview_py3 import ProfilePreview
    from .profile_response_py3 import ProfileResponse
    from .save_profile_request_py3 import SaveProfileRequest
    from .test_proxy_request_py3 import TestProxyRequest
    from .test_proxy_response_py3 import TestProxyResponse, TestProxyResponseException
    from .update_profile_request_py3 import UpdateProfileRequest
    from .user_info_response_py3 import UserInfoResponse
    from .web_driver_settings_py3 import WebDriverSettings
except (SyntaxError, ImportError):
    from .device import Device
    from .os import Os
    from .browser import Browser
    from .base_profile import BaseProfile
    from .base_profile_preview import BaseProfilePreview
    from .base_profile_search_parameters import BaseProfileSearchParameters
    from .browser_cookie import BrowserCookie
    from .cookie_request import CookieRequest
    from .webgl_spoofing_options import WebglSpoofingOptions
    from .webgl_spoofing_type_webgl_spoofing_options_multi_level_choice import WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice
    from .timezone_spoofing_type_timezone_multi_level_choice import TimezoneSpoofingTypeTimezoneMultiLevelChoice
    from .geolocation_spoofing_options import GeolocationSpoofingOptions
    from .geolocation_spoofing_type_geolocation_spoofing_options_multi_level_choice import GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice
    from .server import Server
    from .proxy_connection_type_server_multi_level_choice import ProxyConnectionTypeServerMultiLevelChoice
    from .web_rtc_spoofing_options import WebRtcSpoofingOptions
    from .web_rtc_spoofing_type_web_rtc_spoofing_options_multi_level_choice import WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice
    from .font_spoofing_type_font_ilist_multi_level_choice import FontSpoofingTypeFontIListMultiLevelChoice
    from .plugin_spoofing_type_plugin_ilist_multi_level_choice import PluginSpoofingTypePluginIListMultiLevelChoice
    from .screen_spoofing_type_screen_size_multi_level_choice import ScreenSpoofingTypeScreenSizeMultiLevelChoice
    from .create_profile_request import CreateProfileRequest
    from .load_profile_request import LoadProfileRequest
    from .preference import Preference
    from .problem_response import ProblemResponse, ProblemResponseException
    from .status_response import StatusResponse
    from .profile_preview import ProfilePreview
    from .profile_response import ProfileResponse
    from .save_profile_request import SaveProfileRequest
    from .test_proxy_request import TestProxyRequest
    from .test_proxy_response import TestProxyResponse, TestProxyResponseException
    from .update_profile_request import UpdateProfileRequest
    from .user_info_response import UserInfoResponse
    from .web_driver_settings import WebDriverSettings

__all__ = [
    'Device',
    'Os',
    'Browser',
    'BaseProfile',
    'BaseProfilePreview',
    'BaseProfileSearchParameters',
    'BrowserCookie',
    'CookieRequest',
    'WebglSpoofingOptions',
    'WebglSpoofingTypeWebglSpoofingOptionsMultiLevelChoice',
    'TimezoneSpoofingTypeTimezoneMultiLevelChoice',
    'GeolocationSpoofingOptions',
    'GeolocationSpoofingTypeGeolocationSpoofingOptionsMultiLevelChoice',
    'Server',
    'ProxyConnectionTypeServerMultiLevelChoice',
    'WebRtcSpoofingOptions',
    'WebRtcSpoofingTypeWebRtcSpoofingOptionsMultiLevelChoice',
    'FontSpoofingTypeFontIListMultiLevelChoice',
    'PluginSpoofingTypePluginIListMultiLevelChoice',
    'ScreenSpoofingTypeScreenSizeMultiLevelChoice',
    'CreateProfileRequest',
    'LoadProfileRequest',
    'Preference',
    'ProblemResponse', 'ProblemResponseException',
    'StatusResponse',
    'ProfilePreview',
    'ProfileResponse',
    'SaveProfileRequest',
    'TestProxyRequest',
    'TestProxyResponse', 'TestProxyResponseException',
    'UpdateProfileRequest',
    'UserInfoResponse',
    'WebDriverSettings',
]
