# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GeolocationSpoofingOptions(Model):
    """When the Geolocation spoofing is set to manual these extra settings will be
    used as well.

    All required parameters must be populated in order to send to Azure.

    :param latitude: Required. From -90 to 90
    :type latitude: float
    :param longitude: Required. From -180 to 180
    :type longitude: float
    """

    _validation = {
        'latitude': {'required': True},
        'longitude': {'required': True},
    }

    _attribute_map = {
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
    }

    def __init__(self, *, latitude: float, longitude: float, **kwargs) -> None:
        super(GeolocationSpoofingOptions, self).__init__(**kwargs)
        self.latitude = latitude
        self.longitude = longitude
