# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Preference(Model):
    """Represents a Key-Value pair where Value can be a string or a boolean or an
    integer.

    All required parameters must be populated in order to send to Azure.

    :param key: Required. Key of the preference
    :type key: str
    :param value: Required. Value of the preference. It can a string or a
     boolean or an integer
    :type value: object
    """

    _validation = {
        'key': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'key': {'key': 'key', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, *, key: str, value, **kwargs) -> None:
        super(Preference, self).__init__(**kwargs)
        self.key = key
        self.value = value
