# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TimezoneSpoofingTypeTimezoneMultiLevelChoice(Model):
    """TimezoneSpoofingTypeTimezoneMultiLevelChoice.

    All required parameters must be populated in order to send to Azure.

    :param value: Required. Possible values include: 'automatic', 'manual',
     'off'
    :type value: str or ~kameleo.local_api_client.models.enum
    :param extra: When the Timezone spoofing is set to manual the timezone in
     Iana format is required. For example: America/Grenada
    :type extra: str
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'value': {'key': 'value', 'type': 'str'},
        'extra': {'key': 'extra', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TimezoneSpoofingTypeTimezoneMultiLevelChoice, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.extra = kwargs.get('extra', None)
