# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TestProxyRequest(Model):
    """TestProxyRequest.

    All required parameters must be populated in order to send to Azure.

    :param proxy: Required.
    :type proxy:
     ~kameleo.local_api_client.models.ProxyConnectionTypeServerMultiLevelChoice
    """

    _validation = {
        'proxy': {'required': True},
    }

    _attribute_map = {
        'proxy': {'key': 'proxy', 'type': 'ProxyConnectionTypeServerMultiLevelChoice'},
    }

    def __init__(self, **kwargs):
        super(TestProxyRequest, self).__init__(**kwargs)
        self.proxy = kwargs.get('proxy', None)
